RenderPipeline

Struct RenderPipeline 

pub struct RenderPipeline {
    pub label: String,
    /* private fields */
}
Stores a render pipeline.

Example

use wde_wgpu::render_pipeline::{DepthStencilDescriptor, RenderPipeline, RenderTopology, ShaderStages};

let mut pipeline = RenderPipeline::new("gbuffer");
pipeline
    .set_shader(include_str!("../../../res/pbr/gbuffer_vert.wgsl"), ShaderStages::VERTEX)
    .set_shader(include_str!("../../../res/pbr/gbuffer_frag.wgsl"), ShaderStages::FRAGMENT)
    .set_topology(RenderTopology::TriangleList)
    .set_depth(DepthStencilDescriptor { enabled: true, write: true, compare: wgpu::CompareFunction::Less })
    .set_bind_groups(layouts)
    .add_push_constant(ShaderStages::VERTEX, 0, 64)
    .init(instance)
    .expect("shaders validated");
assert!(pipeline.is_initialized());

let _wgpu_pipeline = pipeline.get_pipeline().unwrap();

Fields

label: String

Implementations

Source

impl RenderPipeline

pub fn new(label: &str) -> Self

Create a new render pipeline. By default, the render pipeline does not have a depth or stencil. By default, the primitive topology is Topology::TriangleList. By default, the cull mode is Some(Face::Back). By default, the sample count is 1. By default, this pipeline expects a vertex buffer to be used.

Arguments
  • label - Label of the render pipeline for debugging.
pub fn set_shader( &mut self, shader: &str, shader_type: ShaderStages, ) -> &mut Self

Set a given shader.

Arguments
  • shader - The shader source code.
  • shader_type - The shader type.
pub fn set_topology(&mut self, topology: RenderTopology) -> &mut Self

Set the primitive topology.

Arguments
  • topology - The primitive topology.
pub fn set_depth(&mut self, depth: DepthDescriptor) -> &mut Self

Set the configuration of the depth/stencil attachment.

pub fn set_cull_mode(&mut self, cull_mode: Option<Face>) -> &mut Self

Set the cull mode. None means no culling.

pub fn set_bind_groups(&mut self, layout: Vec<BindGroupLayout>) -> &mut Self

Add a set of bind groups via its layout to the render pipeline. Note that the order of the bind groups will be the same as the order of the bindings in the shaders.

Arguments
  • layout - The bind group layout.
pub fn set_render_targets(&mut self, targets: Vec<TextureFormat>) -> &mut Self

Set the render targets of the render pipeline.

Arguments
  • targets - The render targets.
pub fn set_sample_count(&mut self, count: u32) -> &mut Self

Set the sample count for multisampling.

Arguments
  • count - The sample count.
pub fn set_use_vertices_buffer(&mut self, use_buffer: bool) -> &mut Self

Set whether the pipeline uses a vertex buffer.

Arguments
  • use_buffer - Whether to use a vertex buffer.
pub fn set_fragment_blend(&mut self, blend: Option<BlendState>) -> &mut Self

Set the blend state for the fragment shader.

Arguments
  • blend - The blend state.
pub fn add_push_constant( &mut self, stages: ShaderStages, offset: u32, size: u32, )

Add a push constant to the render pipeline.

Arguments
  • stages - The shader stages.
  • offset - The offset of the push constant.
  • size - The size of the push constant.
pub fn init( &mut self, instance: &RenderInstanceData<'_>, ) -> Result<(), RenderError>

Initialize a new render pipeline.

Arguments
  • instance - Render instance.
Returns
  • Result<(), RenderError> - The result of the initialization.
pub fn get_pipeline(&self) -> Option<&RenderPipeline>

Get the render pipeline.

Returns
  • Option<&RenderPipelineRef> - The render pipeline.
pub fn get_layout(&self) -> Option<&PipelineLayout>

Get the pipeline layout.

Returns
  • Option<&PipelineLayout> - The pipeline layout.
pub fn is_initialized(&self) -> bool

Check if the render pipeline is initialized.

Returns
  • bool - True if the render pipeline is initialized, false otherwise.