StencilState

Type Alias StencilState 

pub type StencilState = StencilState;
Depth

Aliased Type

#[repr(C)]
pub struct StencilState { pub front: StencilFaceState, pub back: StencilFaceState, pub read_mask: u32, pub write_mask: u32, }

Fields

front: StencilFaceState

Front face mode.

back: StencilFaceState

Back face mode.

read_mask: u32

Stencil values are AND’d with this mask when reading and writing from the stencil buffer. Only low 8 bits are used.

write_mask: u32

Stencil values are AND’d with this mask when writing to the stencil buffer. Only low 8 bits are used.